@@ -2,8 +2,8 @@ from os import environ as env
 
 try:
     # OAuth2 client ID and secret
-    CLIENT_ID = env['CLIENT_ID']
-    CLIENT_SECRET = env['CLIENT_SECRET']
+    CLIENT_ID = ''#env['CLIENT_ID']
+    CLIENT_SECRET = ''#env['CLIENT_SECRET']
 
     # Just use client secret as key for signing session cookies
     SECRET_KEY = CLIENT_SECRET
